"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRedisClientListProvider = exports.createRedisClientProvider = void 0;
const ioredis_1 = require("ioredis");
const common_constant_1 = require("../constants/common.constant");
const redis_constant_1 = require("../constants/redis.constant");
const redis_util_1 = require("../utils/redis.util");
const createRedisClientProvider = () => {
    return common_constant_1.namespaces.map(namespace => ({
        provide: namespace,
        useFactory: (redisUtil) => redisUtil.getClient(namespace),
        inject: [redis_util_1.RedisUtil]
    }));
};
exports.createRedisClientProvider = createRedisClientProvider;
const createRedisClientListProvider = () => ({
    provide: redis_constant_1.REDIS_CLIENT_LIST_PROVIDER,
    useFactory: ({ defaultOptions, config }) => {
        const clientList = new Map();
        if (!config)
            clientList.set(redis_constant_1.DEFAULT_REDIS_CLIENT_PROVIDER, createClient(defaultOptions));
        if (Array.isArray(config)) {
            for (const option of config) {
                clientList.set(option.namespace ?? redis_constant_1.DEFAULT_REDIS_CLIENT_PROVIDER, createClient({ ...defaultOptions, ...option }));
            }
        }
        else {
            clientList.set(config.namespace ?? redis_constant_1.DEFAULT_REDIS_CLIENT_PROVIDER, createClient({ ...defaultOptions, ...config }));
        }
        return clientList;
    },
    inject: [common_constant_1.OPTIONS_PROVIDER]
});
exports.createRedisClientListProvider = createRedisClientListProvider;
const createClient = (clientOptions) => {
    const { onClientCreated, ...redisOptions } = clientOptions;
    const client = new ioredis_1.default(redisOptions);
    if (onClientCreated)
        onClientCreated(client);
    return client;
};
